## Sources

### Photoswipe
https://photoswipe.com/
https://cdnjs.com/libraries/photoswipe


### Font Awesome

We want 4.7, the last version with an open license as far as I remember, but
[perhaps I'm wrong](https://stackoverflow.com/questions/67504930).

https://fontawesome.com/v4/
https://cdnjs.com/libraries/font-awesome/4.7.0
